package org.jeecg.modules.report.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.common.collect.Lists;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.dto.report.CostAccountingReqDTO;
import org.jeecg.common.dto.report.CostAccountingRespDTO;
import org.jeecg.common.dto.report.ProStatisticsRespDTO;
import org.jeecg.modules.archives.entity.ProjectManageArchives;
import org.jeecg.modules.archives.entity.ProjectManageArchivesAndBusiness;
import org.jeecg.modules.archives.service.ProjectManageArchivesAndBusinessService;
import org.jeecg.modules.archives.service.ProjectManageArchivesService;
import org.jeecg.modules.report.mapper.ProReportMapper;
import org.jeecg.modules.report.service.ProReportService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.math.BigDecimal;
import java.util.List;

 /**
   * @Author jihaosen
   * @date 2021/3/11
   */
@Service
public class ProReportServiceImpl implements ProReportService {
    @Autowired
    private ProjectManageArchivesService projectManageArchivesService;
    @Autowired
    private ProjectManageArchivesAndBusinessService projectManageArchivesAndBusinessService;
    @Autowired
    private ProReportMapper proReportMapper;

    /**
     * @desc 获取成本核算数据
     */
    @Override
    public List<CostAccountingRespDTO> getCostAccountingData(CostAccountingReqDTO reqDTO) {
        //获取项目档案
        List<CostAccountingRespDTO> respDTOS = proReportMapper.getCostAccountingData(reqDTO);
        for(CostAccountingRespDTO respDTO : respDTOS){
           BigDecimal totalTax = respDTO.getProIncome().add(respDTO.getImIncome()).add(respDTO.getSeIncome()).add(respDTO.getOtherIncome())
                   .subtract(respDTO.getProPayment()).add(respDTO.getImPayment()).subtract(respDTO.getDePayment()).subtract(respDTO.getOtherPayment());
            respDTO.setTotalTax(totalTax);

        }
        return respDTOS;
    }

     /**
      * @desc 项目情况统计表
      */
     @Override
     public List<ProStatisticsRespDTO> getProStatistics(CostAccountingReqDTO reqDTO) {
         QueryWrapper<ProjectManageArchives> queryWrapper = new QueryWrapper();
         queryWrapper.eq("del_flag", "0").eq("id", reqDTO.getId());
         if(StringUtils.isNotBlank(reqDTO.getPkOrg())){
             queryWrapper.eq("pk_org", reqDTO.getPkOrg());
         }

         ProjectManageArchives projectManageArchives = projectManageArchivesService.getOne(queryWrapper);

         List<ProStatisticsRespDTO> respDTOS = getProStatisticsData(projectManageArchives);
         return respDTOS;
     }

     private List<ProStatisticsRespDTO> getProStatisticsData(ProjectManageArchives projectManageArchives) {
         QueryWrapper<ProjectManageArchivesAndBusiness> queryWrapper = new QueryWrapper<>();
         queryWrapper.eq("del_flag", "0")
                 .eq("pro_archives_id", projectManageArchives.getId());
         List<ProStatisticsRespDTO> respDTOS = projectManageArchivesService.getBusinessData(queryWrapper);

         //TODO 待定
         return respDTOS;
     }
 }

